@@ -1,7 +1,6 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
- *  Copyright (C) 1998--1999  Marcus G. Daniels <mgd@swarm.org>
- *  Copyright (C) 1998--1999  The R Development Core Team
+ *  Copyright (C) 1998-2001  Marcus G. Daniels <mgd@swarm.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -207,6 +206,50 @@ get_string_type (SEXP call, SEXP vec)
   return stid;
 }
 
+static void
+load_scalar (SEXP call, hid_t dataset, hid_t space, SEXP obj)
+{
+  SEXPTYPE type = TYPEOF (obj);
+  void *buf;
+  hid_t tid, memtid;
+
+  if ((tid = H5Dget_type (dataset)) < 0)
+    errorcall (call, "Unable to get type for dataset");
+
+  if (H5Tget_class (tid) == H5T_COMPOUND)
+    errorcall (call, "Not equipped to load compound scalar");
+
+  switch (type) {
+
+  case STRSXP:
+      memtid = make_sexp_ref_type (call);
+      buf = STRING_PTR (obj);
+      break;
+  case REALSXP:
+      memtid = H5T_NATIVE_DOUBLE;
+      buf = REAL (obj);
+      break;
+  case INTSXP:
+      memtid = H5T_NATIVE_INT;
+      buf = INTEGER (obj);
+      break;
+  case LGLSXP:
+      memtid = H5T_NATIVE_UINT;
+      buf = INTEGER (obj);
+      break;
+  default:
+      errorcall (call, "Can't get type for R type: %d (IO)", type);
+      /* unreached (-Wall): */ memtid = tid;  buf = &tid;
+  }
+  
+  if (H5Dread (dataset,
+               memtid,
+               space,
+               space,
+               H5P_DEFAULT,
+               buf) < 0)
+    errorcall (call, "Unable to read dataset");
+}
 
 static void
 vector_io (SEXP call, int writeflag, hid_t dataset, hid_t space, SEXP obj)
@@ -1192,7 +1235,17 @@ hdf5_process_object (hid_t id, const char *name, void *client_data)
         Rprintf ("Dataset has rank %d\n",rank);
 
       if (rank == 0)
-        warningcall (iinfo->call, "Ignoring dataset %s as it has rank 0", name);
+        {
+          SEXP obj;
+
+          if (hdf5_global_verbosity > 2) 
+            Rprintf ("Loading scalar\n");
+          PROTECT (obj = allocVector (type, 1));
+          load_scalar (iinfo->call, dataset, space, obj);
+          iinfo->add (iinfo, name, obj);
+          hdf5_load_attributes (iinfo->call, dataset, obj, name);
+          UNPROTECT (1);
+        }
       else
         {
           hsize_t dims[rank];
@@ -1302,7 +1355,7 @@ hdf5_process_object (hid_t id, const char *name, void *client_data)
           else
             {
               SEXP obj;
-              
+
               if (rank == 1)
                 {
                   if (hdf5_global_verbosity > 2) 
